from pathlib import Path

from django.contrib import admin, messages

from .models import Page
from .parser import import_pages


def reimport(modeladmin, request, queryset):
    num_pages = len(list(import_pages(True, set(page.url for page in queryset))))

    if num_pages == 0:
        modeladmin.message_user(
            request, "Es wurden keine Seiten reimportiert.", messages.WARNING
        )
    elif num_pages == 1:
        modeladmin.message_user(
            request, "Eine Seite wurde reimportiert.", messages.SUCCESS
        )
    else:
        modeladmin.message_user(
            request, f"{num_pages} Seiten wurden reimportiert.", messages.SUCCESS
        )


@admin.register(Page)
class PageAdmin(admin.ModelAdmin):
    fields = (
        "url",
        "content",
        "title",
        "visible",
        "kind",
        "show_in_footer_nav",
        "show_in_main_nav",
    )
    list_display = (
        "url",
        "title",
        "visible",
        "kind",
        "show_in_footer_nav",
        "show_in_main_nav",
    )
    actions = (reimport,)
